/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-10-22 15:27:49.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.service.impl;

import cn.com.qmth.examcloud.core.print.common.jpa.OrderBuilder;
import cn.com.qmth.examcloud.core.print.common.jpa.SearchBuilder;
import cn.com.qmth.examcloud.core.print.common.jpa.SpecUtils;
import cn.com.qmth.examcloud.core.print.common.utils.Check;
import cn.com.qmth.examcloud.core.print.entity.CourseStatistic;
import cn.com.qmth.examcloud.core.print.repository.CourseStatisticRepository;
import cn.com.qmth.examcloud.core.print.service.CourseStatisticService;
import cn.com.qmth.examcloud.core.print.service.bean.coursestatistic.CourseStatisticConvert;
import cn.com.qmth.examcloud.core.print.service.bean.coursestatistic.CourseStatisticInfo;
import cn.com.qmth.examcloud.core.print.service.bean.coursestatistic.CourseStatisticQuery;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

/**
 * @author: fengdesheng
 * @since: 2018/10/17
 */
@Service
public class CourseStatisticServiceImpl implements CourseStatisticService {
    private static final Logger log = LoggerFactory.getLogger(CourseStatisticServiceImpl.class);
    @Autowired
    private CourseStatisticRepository courseStatisticsRepository;

    @Override
    public Page<CourseStatisticInfo> getCourseStatisticList(CourseStatisticQuery query) {
        Check.isNull(query, "查询参数不能为空！");
        //查询条件
        SearchBuilder searches = new SearchBuilder();
        if (query.getOrgId() != null) {
            searches.eq("orgId", query.getOrgId());
        }
        if (query.getExamId() != null) {
            searches.eq("examId", query.getExamId());
        }
        if (query.getCourseId() != null) {
            searches.eq("courseId", query.getCourseId());
        }
        if (query.getPaperBindingStatus() != null) {
            searches.eq("paperBindingStatus", query.getPaperBindingStatus());
        }
        if (query.getPaperId() != null) {
            searches.eq("coursePaper.id", query.getPaperId());
        }
        Specification<CourseStatistic> spec = SpecUtils.buildSearchers(CourseStatistic.class, searches.build());
        //排序条件
        OrderBuilder orders = new OrderBuilder().desc("id");
        //分页条件
        Pageable pageable = SpecUtils.buildPageable(query.getPageNo(), query.getPageSize(), orders.build());
        Page<CourseStatistic> page = courseStatisticsRepository.findAll(spec, pageable);
        return CourseStatisticConvert.ofPage(page);
    }

    @Override
    public void initCourseStatistics(Long orgId, Long examId, Long[] courseIds) {
        //todo
    }

    @Override
    public void initCourseStatistics() {
        //todo
    }

}